/* 
 * <img data-src="image1.png" src="images/lazyplaceholder.png" alt="">
 * 
 */
document.addEventListener("DOMContentLoaded", function () {
    var lazyloadImages = document.querySelectorAll("img[data-src]");
    if ("IntersectionObserver" in window) {
        var imageObserver = new IntersectionObserver(function (entries, observer) {
            entries.forEach(function (entry) {
                if (entry.isIntersecting) {
                    var image = entry.target;
                    image.src = image.src.replace(/lazyplaceholder.png/,  image.dataset.src)
                    image.removeAttribute("data-src");
                    imageObserver.unobserve(image);
                }
            });
        });

        lazyloadImages.forEach(function (image) {
            imageObserver.observe(image);
        });
    } else {
        var lazyloadThrottleTimeout;
        lazyloadImages.forEach(function (image) {
            if (image.offsetTop < (window.innerHeight)) {
                image.src = image.src.replace(/lazyplaceholder.png/,  image.dataset.src)
                image.removeAttribute("data-src");
            }
        });
        lazyloadImages = document.querySelectorAll("img[data-src]");

        function lazyload() {
            if (lazyloadThrottleTimeout) {
                clearTimeout(lazyloadThrottleTimeout);
            }

            lazyloadThrottleTimeout = setTimeout(function () {
                var scrollTop = window.pageYOffset;
                lazyloadImages.forEach(function (image) {
                    if (image.offsetTop < (window.innerHeight + scrollTop)) {
                        image.src = image.src.replace(/lazyplaceholder.png/,  image.dataset.src)
                        image.removeAttribute("data-src");
                        
                    }
                });
                lazyloadImages = document.querySelectorAll("img[data-src]");
                if (lazyloadImages.length == 0) {
                    document.removeEventListener("scroll", lazyload);
                    window.removeEventListener("resize", lazyload);
                    window.removeEventListener("orientationChange", lazyload);
                }
            }, 20);
        }

        document.addEventListener("scroll", lazyload);
        window.addEventListener("resize", lazyload);
        window.addEventListener("orientationChange", lazyload);
    }
});
